{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template core/emoji/auto_complete

    This template will render the emoji auto complete.

    Classes required for JS:
    * none

    Data attributes required for JS:
    *

    Context variables required for this template:
    *

    Example context (json):
    {}

}}

<div
    data-region="emoji-auto-complete"
    class="emoji-auto-complete bg-white d-flex align-items-center"
>
    {{#emojis}}
        <button
            type="button"
            class="btn btn-icon p-0 rounded-3 emoji-button {{#active}}active{{/active}}"
            title="{{displayshortname}}"
            data-region="emoji-button"
            data-unified="{{unified}}"
            data-short-name="{{shortname}}"
        >
            {{emojitext}}
        </button>
    {{/emojis}}
</div>
